package com.vendor.burn.model.config;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.log.Log;
import com.vendor.burn.model.BoardConfig;
import com.vendor.burn.model.LocalConfig;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.cmdline.CmdLineParam;
import com.vendor.burn.model.cmdline.adapter.CommonAdapter;
import com.vendor.burn.model.devices.burners.CommonBurner;
import com.vendor.burn.utilitily.ConvertUtils;
import com.vendor.burn.utilitily.FileUtils;
import com.vendor.burn.utilitily.IPUtils;
import com.vendor.burn.utilitily.PropertiesUtility;
import java.io.File;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import org.eclipse.osgi.util.NLS;
import org.vendor.tftp.tool.TFTPService;

public class BurnConfig extends PropertiesUtility {
  public static final String KEY_CHIPNAME = "chipName";
  
  public static final String KEY_XMLPATH = "xmlPath";
  
  public static final String KEY_XMLPATHDEFAULT = "xmlPathDefault";
  
  public static final String KEY_PROGRAMMER = "programmer";
  
  public static final String KEY_SERIALPORT = "comport";
  
  public static final String KEY_SERVERIP = "serverip";
  
  public static final String KEY_REMOTETFTPSERVER = "remotetftpserver";
  
  public static final String KEY_REMOTETFTPSERVERDIR = "remotetftpserverdir";
  
  public static final String KEY_IPADDR = "ipaddr";
  
  public static final String KEY_NETMASK = "netmask";
  
  public static final String KEY_GATEWAYIP = "gatewayip";
  
  public static final String KEY_UDPPORT = "udpport";
  
  public static final String KEY_ETHADDR = "ethaddr";
  
  public static final String IS_WRITE_ETHADDR = "isWriteEthaddr";
  
  public static final String IS_SEND_NOT_USE_FLASH_MAC_CMD = "isSendNotUseFlashMacCmd";
  
  public static final String PORT_CONFIGURABLE = "portConfigurable";
  
  public static final String PORT = "port";
  
  public static final String SERIAL_COMMAND_TIMEOUT = "serialCommandTimeout";
  
  public static final String TFTP_TIMEOUT = "tftpTimeout";
  
  public static final String FRAME_COMMUNICATION_TIMEOUT = "typeFrameFrequency";
  
  public static final String IS_SOCKET = "isSocket";
  
  public static final String SERIAL_SERVER_IP = "serialServerIp";
  
  public static final String SERIAL_SERVER_PORT = "serialServerPort";
  
  public static final String KEY_TRANSFER_MODE = "mode";
  
  public static final String KEY_TRANSFER_USBTOETHERNET = "usbToEthernet";
  
  public static final String KEY_IS_SEND_USBTONET_CMD = "isSendUsbToNetCmd";
  
  public static final String KEY_TRANSFER_USBSERIALNUMBER = "usbSerialNumber";
  
  public static final String KEY_TRANSFER_USBDEVICENUMBER = "usbDeviceNumber";
  
  public static final String KEY_JTAG_CONFIG_FREQUENCY = "frequency";
  
  public static final String KEY_JTAG_SMALL_BOARD_MODEL = "smallboardmodel";
  
  public static final String BURN_CONFIG_FILE = "burn.config";
  
  public static final String IS_BURN_SPLIT_IAMGE = "isSplit";
  
  public static final String IS_CHECK_XML = "isCheckXml";
  
  public static final String IS_BURN_PROGRAMMER = "isBurnProgrammer";
  
  public static final String BAUD_RATE = "baudRate";
  
  public static final String SERIAL_BAUD = "serialBaud";
  
  public static final String CHIP_TYPE = "chipType";
  
  public static final String IS_SEND_UART_COMMAND = "isSendUartCommand";
  
  public static final String USERNAME = "userName";
  
  public static final String PASSWORD = "passWord";
  
  private static final String IS_ADD_HOSTNAME = "isAddHostName";
  
  private static String chipName;
  
  private static String xmlPath;
  
  private static String programmer;
  
  private static LocalConfig localConfig;
  
  private static BoardConfig boardConfig;
  
  private static boolean portConfigurable = false;
  
  private static int port = 69;
  
  private static boolean isSocket = false;
  
  private static String serialServerIp;
  
  private static int serialServerPort = 10029;
  
  private static TransferWay transferway;
  
  private static int dwTimeout = 13;
  
  private static boolean isUSBToEthernet = false;
  
  private static boolean isSendUsbToNetCmd = false;
  
  private static String usbSerialNumber = "0x000001";
  
  private static String usbDeviceName = "-1";
  
  private static String baudRate = "300K";
  
  private boolean loadResult = false;
  
  private static int baud = 115200;
  
  public static int chipType = 0;
  
  private static boolean isSplit = false;
  
  private static boolean isCheckXml = false;
  
  private static boolean isBurnProgrammer = true;
  
  private static boolean isSendUartCommand = false;
  
  private static int beforeBurningDelayTime = 20000;
  
  private static boolean isSendFlashMacCmd = false;
  
  public BurnConfig(CmdLineParam cmdLineParam) {
    if (cmdLineParam != null) {
      String burnXmlPath = cmdLineParam.getXmlPath();
      setXmlPath(burnXmlPath);
      this.loadResult = loadBurnConfig(cmdLineParam);
    } 
  }
  
  protected boolean getParamBoolValue(String keyName) {
    return getParamBoolValue(keyName, "burn.config");
  }
  
  protected int getParamIntValue(String keyName) {
    return getParamIntValue(keyName, "burn.config");
  }
  
  protected boolean loadBurnConfig(CmdLineParam cmdLineParam) {
    String cmdLineBurnConfigPath = null;
    if (cmdLineParam != null)
      cmdLineBurnConfigPath = cmdLineParam.getBurnConfigPath(); 
    String path = null;
    if (cmdLineBurnConfigPath != null && !cmdLineBurnConfigPath.isEmpty() && cmdLineBurnConfigPath != "") {
      path = cmdLineBurnConfigPath;
    } else {
      path = FileUtils.toAbsolutePath("config" + File.separator + "burn.config");
    } 
    if (!FileUtils.isExists(path)) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_FILE_PATH_DONT_EXIST, "burn.config"));
      return false;
    } 
    ArrayList<String> definitionLines = FileUtils.readAllLines(path);
    if (definitionLines == null) {
      Log.errorln(NLS.bind("Failed to read the file, the file path is as follows: ", path));
      return false;
    } 
    for (String s : definitionLines) {
      String line = s.trim().replace("\t", "");
      if (line.startsWith("["))
        continue; 
      if (line.contains("=")) {
        String[] ppt = line.split("=");
        if (ppt.length > 1)
          set(ppt[0], ppt[1]); 
      } 
    } 
    if (!addHostName())
      return false; 
    localConfig = new LocalConfig();
    boardConfig = new BoardConfig();
    if (!loadCommonConfig(cmdLineParam))
      return false; 
    if (!loadConfigByTransferway(cmdLineParam))
      return false; 
    Log.println(NLS.bind(Messages.MESSAGE_LOAD_FILE_SUCCESS, "burn.config"));
    return true;
  }
  
  private boolean addHostName() {
    String isAddHostNameStr = queryForString("isAddHostName");
    if (isAddHostNameStr != null && !isAddHostNameStr.isEmpty() && 
      Boolean.valueOf(isAddHostNameStr).booleanValue() && 
      !IPUtils.addHostName()) {
      Log.println("add hostName error");
      return false;
    } 
    return true;
  }
  
  private boolean loadConfigByTransferway(CmdLineParam cmdLineParam) {
    String transferwayMode = getTransferway().name().toLowerCase();
    if ((transferwayMode.contains("net") || transferwayMode.contains("udp") || transferwayMode
      .contains("serial") || TransferWay.I2CBootrom == getTransferway() || 
      isSendUartCommand()) && 
      !loadSerialConfig(cmdLineParam))
      return false; 
    if ((transferwayMode.contains("net") || transferwayMode.contains("udp")) && 
      !loadTFTPConfig(cmdLineParam))
      return false; 
    if (transferwayMode.contains("udp")) {
      String udpPortStr = queryForString("udpport");
      if (udpPortStr != null && !udpPortStr.isEmpty())
        try {
          boardConfig.setUdpPort(Integer.parseInt(udpPortStr));
        } catch (NumberFormatException e) {
          Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "udpport"));
          return false;
        }  
    } 
    if (transferwayMode.contains("jtag") && 
      !loadJtagConfig())
      return false; 
    if (transferwayMode.contains("usb") && TransferWay.UsbTransNet != getTransferway() && 
      !loadUsbConfig())
      return false; 
    return true;
  }
  
  private boolean loadTFTPConfig(CmdLineParam cmdLineParam) {
    if (!loadNetConfig(cmdLineParam))
      return false; 
    String portConfigurable = queryForString("portConfigurable");
    if (portConfigurable == null || portConfigurable.isEmpty()) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "portConfigurable"));
      return false;
    } 
    try {
      setPortConfigurable(Boolean.valueOf(portConfigurable).booleanValue());
    } catch (Exception e) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "portConfigurable"));
      return false;
    } 
    String port = queryCmdLineForString("port", cmdLineParam);
    if (port == null || port.isEmpty()) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "port"));
      return false;
    } 
    try {
      setPort(Integer.parseInt(port.trim().toString()));
    } catch (NumberFormatException numberFormat) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "port"));
      return false;
    } 
    String tftpTimeout = queryForString("tftpTimeout");
    if (tftpTimeout == null || tftpTimeout.isEmpty()) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "tftpTimeout"));
      return false;
    } 
    try {
      TFTPService.setTftpTimeout(Integer.parseInt(tftpTimeout.trim().toString()));
    } catch (NumberFormatException numberFormat) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "tftpTimeout"));
      return false;
    } 
    String transferUSBToEtherNetStr = queryForString("usbToEthernet");
    if (transferUSBToEtherNetStr != null && !transferUSBToEtherNetStr.isEmpty())
      setUSBToEthernet(TransferWay.converntUSBToEtherNet(transferUSBToEtherNetStr)); 
    String isSendUsbToNetCmdStr = queryForString("isSendUsbToNetCmd");
    if (isSendUsbToNetCmdStr != null && !isSendUsbToNetCmdStr.isEmpty())
      setSendUsbToNetCmd(Boolean.valueOf(isSendUsbToNetCmdStr).booleanValue()); 
    return true;
  }
  
  private boolean loadSerialConfig(CmdLineParam cmdLineParam) {
    String comPortStr = queryCmdLineForString("comport", cmdLineParam);
    if (comPortStr != null && !comPortStr.isEmpty()) {
      localConfig.setComPort(comPortStr);
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "comport"));
      return false;
    } 
    String baudStr = queryCmdLineForString("serialBaud", cmdLineParam);
    if (baudStr != null && baudStr.matches("[0-9]+"))
      try {
        baud = Integer.parseInt(baudStr);
      } catch (NumberFormatException numberFormatException) {} 
    String chipTypeStr = queryCmdLineForString("chipType", cmdLineParam);
    if (chipTypeStr != null && !chipTypeStr.isEmpty())
      try {
        chipType = ConvertUtils.stringToInt(chipTypeStr);
      } catch (NumberFormatException numberFormatException) {} 
    if (!loadSocketConfig(cmdLineParam))
      return false; 
    String beforeBurningDelayTimeStr = cmdLineParam.getBeforeBurningDelayTime();
    if (beforeBurningDelayTimeStr != null && !beforeBurningDelayTimeStr.isEmpty())
      setBeforeBurningDelayTime(ConvertUtils.stringToInt(beforeBurningDelayTimeStr)); 
    return true;
  }
  
  private boolean loadCommonConfig(CmdLineParam cmdLineParam) {
    String transferModeStr = queryCmdLineForString("mode", cmdLineParam);
    if (transferModeStr != null && !transferModeStr.isEmpty()) {
      if (getTransferway() == null)
        setTransferway(TransferWay.convernt(transferModeStr)); 
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "mode"));
      return false;
    } 
    String chipNameStr = queryCmdLineForString("chipName", cmdLineParam);
    if (chipNameStr == null || chipNameStr.isEmpty()) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "chipName"));
      return false;
    } 
    String upperCaseChipName = CommonAdapter.convertChipName(chipNameStr);
    setChipName(upperCaseChipName);
    if (xmlPath == null) {
      String xmlPathStr = queryForString("xmlPath");
      if (xmlPathStr == null || xmlPathStr.isEmpty()) {
        Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "xmlPath"));
        return false;
      } 
      xmlPathStr = getGbkXmlPath(xmlPathStr);
      setXmlPath(xmlPathStr);
    } 
    String programmerPath = queryForString("programmer");
    if (programmerPath != null && !programmerPath.isEmpty())
      setProgrammer(programmerPath); 
    String ethaddrStr = queryForString("ethaddr");
    if (ethaddrStr != null && !ethaddrStr.isEmpty()) {
      boardConfig.setMac(ethaddrStr);
      String isWriteEthaddr = queryForString("isWriteEthaddr");
      if (isWriteEthaddr != null && !isWriteEthaddr.isEmpty())
        boardConfig.setWriteEthaddr(Boolean.valueOf(isWriteEthaddr).booleanValue()); 
    } else {
      String generatorMAC = IPUtils.generatorMAC();
      boardConfig.setMac(generatorMAC);
      boardConfig.setWriteEthaddr(false);
    } 
    String isSplitStr = queryForString("isSplit");
    if (isSplitStr != null && !isSplitStr.isEmpty())
      setSplit(Boolean.valueOf(isSplitStr).booleanValue()); 
    String isCheckXmlStr = queryForString("isCheckXml");
    if (isCheckXmlStr != null && !isCheckXmlStr.isEmpty())
      setCheckXml(Boolean.valueOf(isCheckXmlStr).booleanValue()); 
    loadIsBurnProgrammar();
    String isSendUartCommandStr = queryForString("isSendUartCommand");
    if (isSendUartCommandStr != null && !isSendUartCommandStr.isEmpty())
      setSendUartCommand(Boolean.valueOf(isSendUartCommandStr).booleanValue()); 
    String isSendNotUseFlashMacCmdStr = queryForString("isSendNotUseFlashMacCmd");
    if (isSendNotUseFlashMacCmdStr != null && !isSendNotUseFlashMacCmdStr.isEmpty())
      isSendFlashMacCmd = Boolean.valueOf(isSendNotUseFlashMacCmdStr).booleanValue(); 
    return true;
  }
  
  private void loadIsBurnProgrammar() {
    String isBurnProgrammerStr = queryForString("isBurnProgrammer");
    if (isBurnProgrammerStr != null && !isBurnProgrammerStr.isEmpty())
      setBurnProgrammer(Boolean.valueOf(isBurnProgrammerStr).booleanValue()); 
  }
  
  private boolean loadNetConfig(CmdLineParam cmdLineParam) {
    String serveripStr = queryCmdLineForString("serverip", cmdLineParam);
    if (serveripStr != null && !serveripStr.isEmpty()) {
      localConfig.setServerIp(serveripStr);
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "serverip"));
      return false;
    } 
    String remoteTftpServerStr = queryCmdLineForString("remotetftpserver", cmdLineParam);
    localConfig.setRemoteTftpServer(false);
    if (remoteTftpServerStr != null && !remoteTftpServerStr.isEmpty() && 
      remoteTftpServerStr.equalsIgnoreCase("true"))
      localConfig.setRemoteTftpServer(true); 
    String remoteTftpServerDirStr = queryCmdLineForString("remotetftpserverdir", cmdLineParam);
    if (remoteTftpServerDirStr != null && !remoteTftpServerDirStr.isEmpty())
      localConfig.setRemoteTftpServerDir(remoteTftpServerDirStr); 
    String ipaddrStr = queryCmdLineForString("ipaddr", cmdLineParam);
    if (ipaddrStr == null)
      boardConfig.setIp(ipaddrStr); 
    if (ipaddrStr == null || ipaddrStr.isEmpty()) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "ipaddr"));
      return false;
    } 
    boardConfig.setIp(ipaddrStr);
    String netmaskStr = queryCmdLineForString("netmask", cmdLineParam);
    if (netmaskStr == null || netmaskStr.isEmpty()) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "netmask"));
      return false;
    } 
    boardConfig.setSubnetMask(netmaskStr);
    String gatewayipStr = queryCmdLineForString("gatewayip", cmdLineParam);
    if (gatewayipStr == null || gatewayipStr.isEmpty()) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "gatewayip"));
      return false;
    } 
    boardConfig.setGateway(gatewayipStr);
    String transferModeStr = queryCmdLineForString("mode", cmdLineParam);
    if (transferModeStr != null && !transferModeStr.isEmpty()) {
      setTransferway(TransferWay.convernt(transferModeStr));
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "mode"));
      return false;
    } 
    return true;
  }
  
  private boolean loadJtagConfig() {
    String frequency = queryForString("frequency");
    if (frequency == null || frequency.isEmpty()) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "frequency"));
      return false;
    } 
    try {
      boardConfig.setFrequency(Integer.parseInt(frequency));
    } catch (NumberFormatException numberFormat) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "smallboardmodel"));
      return false;
    } 
    String smallboradmodel = queryForString("smallboardmodel");
    if (smallboradmodel != null && !smallboradmodel.isEmpty()) {
      try {
        boardConfig.setSmallboradmodel(Integer.parseInt(smallboradmodel.trim().toString()));
      } catch (NumberFormatException numberFormat) {
        Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "smallboardmodel"));
        return false;
      } 
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "smallboardmodel"));
      return false;
    } 
    return true;
  }
  
  private boolean loadSocketConfig(CmdLineParam cmdLineParam) {
    String isUseSocket = queryCmdLineForString("isSocket", cmdLineParam);
    if (isUseSocket != null && !isUseSocket.isEmpty()) {
      boardConfig.setSocket(Boolean.valueOf(isUseSocket).booleanValue());
      CommonBurner.isSocketTransfer = Boolean.valueOf(isUseSocket).booleanValue();
    } 
    String userName = queryUserNameCmdLineParam("userName", cmdLineParam);
    if (userName != null && !userName.isEmpty())
      boardConfig.setUserName(userName.trim()); 
    String passWord = queryUserNameCmdLineParam("passWord", cmdLineParam);
    if (passWord != null)
      boardConfig.setPassWord(passWord.trim()); 
    if (boardConfig.isSocket()) {
      String socketServerIp = queryCmdLineForString("serialServerIp", cmdLineParam);
      if (socketServerIp != null && !socketServerIp.isEmpty()) {
        boardConfig.setSerialServerIp(socketServerIp.trim());
      } else {
        Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "serialServerIp"));
        return false;
      } 
      String socketServerPort = queryCmdLineForString("serialServerPort", cmdLineParam);
      if (socketServerPort != null && !socketServerPort.isEmpty()) {
        boardConfig.setSerialServerPort(Short.parseShort(socketServerPort.trim().toString()));
      } else {
        Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "serialServerPort"));
        return false;
      } 
      String dwTimeoutStr = queryForString("typeFrameFrequency");
      if (dwTimeoutStr != null && !dwTimeoutStr.isEmpty())
        setDwTimeout(Integer.parseInt(dwTimeoutStr)); 
    } 
    return true;
  }
  
  private boolean loadUsbConfig() {
    String transferUsbSerialNumberStr = queryForString("usbSerialNumber");
    if (transferUsbSerialNumberStr != null && !transferUsbSerialNumberStr.isEmpty()) {
      setUsbSerialNumber(transferUsbSerialNumberStr);
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "usbSerialNumber"));
      return false;
    } 
    String usbDeviceNameStr = queryForString("usbDeviceNumber");
    if (usbDeviceNameStr != null && !usbDeviceNameStr.isEmpty())
      setUsbDeviceName(usbDeviceNameStr); 
    return true;
  }
  
  private String getGbkXmlPath(String xmlPathStr) {
    try {
      String defaultCode = System.getProperty("file.encoding");
      if (defaultCode.toLowerCase().equalsIgnoreCase("gbk")) {
        String xmlPathCodedStr = new String(xmlPathStr.getBytes("GBK"), "UTF-8");
        byte[] bytes = xmlPathCodedStr.getBytes("UTF-8");
        byte[] bytesGbk = (new String(bytes, "UTF-8")).getBytes("GBK");
        xmlPathStr = new String(bytesGbk, "GBK");
        return xmlPathStr;
      } 
      return xmlPathStr;
    } catch (UnsupportedEncodingException unsupportedEncodingException) {
      return xmlPathStr;
    } 
  }
  
  public static String getChipName() {
    return chipName;
  }
  
  public static void setChipName(String chipName) {
    com.vendor.burn.model.config.BurnConfig.chipName = chipName;
  }
  
  public static String getXmlPath() {
    return xmlPath;
  }
  
  public static void setXmlPath(String xmlPath) {
    com.vendor.burn.model.config.BurnConfig.xmlPath = xmlPath;
  }
  
  public static String getProgrammer() {
    return programmer;
  }
  
  public static void setProgrammer(String programmer) {
    com.vendor.burn.model.config.BurnConfig.programmer = programmer;
  }
  
  public static LocalConfig getLocalConfig() {
    return localConfig;
  }
  
  public static void setLocalConfig(LocalConfig localConfig) {
    com.vendor.burn.model.config.BurnConfig.localConfig = localConfig;
  }
  
  public static BoardConfig getBoardConfig() {
    return boardConfig;
  }
  
  public static void setBoardConfig(BoardConfig boardConfig) {
    com.vendor.burn.model.config.BurnConfig.boardConfig = boardConfig;
  }
  
  public static boolean isPortConfigurable() {
    return portConfigurable;
  }
  
  public static void setPortConfigurable(boolean portConfigurable) {
    com.vendor.burn.model.config.BurnConfig.portConfigurable = portConfigurable;
  }
  
  public static int getPort() {
    return port;
  }
  
  public static void setPort(int port) {
    com.vendor.burn.model.config.BurnConfig.port = port;
  }
  
  public static boolean isSocket() {
    return isSocket;
  }
  
  public static void setSocket(boolean isSocket) {
    com.vendor.burn.model.config.BurnConfig.isSocket = isSocket;
  }
  
  public static String getSerialServerIp() {
    return serialServerIp;
  }
  
  public static void setSerialServerIp(String serialServerIp) {
    com.vendor.burn.model.config.BurnConfig.serialServerIp = serialServerIp;
  }
  
  public static int getSerialServerPort() {
    return serialServerPort;
  }
  
  public static void setSerialServerPort(int serialServerPort) {
    com.vendor.burn.model.config.BurnConfig.serialServerPort = serialServerPort;
  }
  
  public static TransferWay getTransferway() {
    return transferway;
  }
  
  public static void setTransferway(TransferWay transferway) {
    com.vendor.burn.model.config.BurnConfig.transferway = transferway;
  }
  
  public static int getDwTimeout() {
    return dwTimeout;
  }
  
  public static void setDwTimeout(int dwTimeout) {
    com.vendor.burn.model.config.BurnConfig.dwTimeout = dwTimeout;
  }
  
  public static boolean isUSBToEthernet() {
    return isUSBToEthernet;
  }
  
  public static void setUSBToEthernet(boolean isUSBToEthernet) {
    com.vendor.burn.model.config.BurnConfig.isUSBToEthernet = isUSBToEthernet;
  }
  
  public boolean isLoadResult() {
    return this.loadResult;
  }
  
  public void setLoadResult(boolean loadResult) {
    this.loadResult = loadResult;
  }
  
  public static String getUsbSerialNumber() {
    return usbSerialNumber;
  }
  
  public static void setUsbSerialNumber(String usbSerialNumber) {
    com.vendor.burn.model.config.BurnConfig.usbSerialNumber = usbSerialNumber;
  }
  
  public static String getUsbDeviceName() {
    return usbDeviceName;
  }
  
  public static void setUsbDeviceName(String usbDeviceName) {
    com.vendor.burn.model.config.BurnConfig.usbDeviceName = usbDeviceName;
  }
  
  public static String getBaudRate() {
    return baudRate;
  }
  
  public static void setBaudRate(String baudRate) {
    com.vendor.burn.model.config.BurnConfig.baudRate = baudRate;
  }
  
  public static int getBaud() {
    return baud;
  }
  
  public static void setBaud(int baud) {
    com.vendor.burn.model.config.BurnConfig.baud = baud;
  }
  
  public static int getChipType() {
    return chipType;
  }
  
  public static void setChipType(int chipType) {
    com.vendor.burn.model.config.BurnConfig.chipType = chipType;
  }
  
  public static boolean isSplit() {
    return isSplit;
  }
  
  public static void setSplit(boolean isSplit) {
    com.vendor.burn.model.config.BurnConfig.isSplit = isSplit;
  }
  
  public static boolean isCheckXml() {
    return isCheckXml;
  }
  
  public static void setCheckXml(boolean isCheckXml) {
    com.vendor.burn.model.config.BurnConfig.isCheckXml = isCheckXml;
  }
  
  public static boolean isBurnProgrammer() {
    return isBurnProgrammer;
  }
  
  public static void setBurnProgrammer(boolean isBurnProgrammer) {
    com.vendor.burn.model.config.BurnConfig.isBurnProgrammer = isBurnProgrammer;
  }
  
  public static boolean isSendUartCommand() {
    return isSendUartCommand;
  }
  
  public static void setSendUartCommand(boolean isSendUartCommand) {
    com.vendor.burn.model.config.BurnConfig.isSendUartCommand = isSendUartCommand;
  }
  
  public static int getBeforeBurningDelayTime() {
    return beforeBurningDelayTime;
  }
  
  public static void setBeforeBurningDelayTime(int beforeBurningDelayTime) {
    com.vendor.burn.model.config.BurnConfig.beforeBurningDelayTime = beforeBurningDelayTime;
  }
  
  public static boolean isSendUsbToNetCmd() {
    return isSendUsbToNetCmd;
  }
  
  public static void setSendUsbToNetCmd(boolean isSendUsbToNetCmd) {
    com.vendor.burn.model.config.BurnConfig.isSendUsbToNetCmd = isSendUsbToNetCmd;
  }
  
  public static boolean isSendFlashMacCmd() {
    return isSendFlashMacCmd;
  }
}
